==> at_commons-3.0.56.tar.gz: lib/src/at_constants_legacy.dart <==
// ignore_for_file: constant_identifier_names
part of 'at_constants.dart';

@Deprecated('Use AtConstants.AT_SIGN instead')
const String AT_SIGN = AtConstants.atSign;

@Deprecated('Use AtConstants.FOR_AT_SIGN instead')
const String FOR_AT_SIGN = AtConstants.forAtSign;

@Deprecated('Use AtConstants.AT_KEY instead')
const String AT_KEY = AtConstants.atKey;

@Deprecated('Use AtConstants.AT_VALUE instead')
const String AT_VALUE = AtConstants.atValue;

@Deprecated('Use AtConstants.AT_DIGEST instead')
const String AT_DIGEST = AtConstants.atDigest;

@Deprecated('Use AtConstants.AT_PKAM_SIGNATURE instead')
const String AT_PKAM_SIGNATURE = AtConstants.atPkamSignature;

@Deprecated('Use AtConstants.AT_PKAM_SIGNING_ALGO instead')
const String AT_PKAM_SIGNING_ALGO = AtConstants.atPkamSigningAlgo;

@Deprecated('Use AtConstants.AT_PKAM_HASHING_ALGO instead')
const String AT_PKAM_HASHING_ALGO = AtConstants.atPkamHashingAlgo;

@Deprecated('Use AtConstants.PUBLIC_SCOPE_PARAM instead')
const String PUBLIC_SCOPE_PARAM = AtConstants.publicScopeParam;

@Deprecated('Use AtConstants.AT_PKAM_PRIVATE_KEY instead')
const String AT_PKAM_PRIVATE_KEY = AtConstants.atPkamPrivateKey;

@Deprecated('Use AtConstants.AT_PKAM_PUBLIC_KEY instead')
const String AT_PKAM_PUBLIC_KEY = AtConstants.atPkamPublicKey;

@Deprecated('Use AtConstants.AT_ENCRYPTION_PUBLIC_KEY instead')
const String AT_ENCRYPTION_PUBLIC_KEY = AtConstants.atEncryptionPublicKey;

@Deprecated('Use AtConstants.AT_ENCRYPTION_PRIVATE_KEY instead')
const String AT_ENCRYPTION_PRIVATE_KEY = AtConstants.atEncryptionPrivateKey;

@Deprecated('Use AtConstants.AT_ENCRYPTION_SHARED_KEY instead')
const String AT_ENCRYPTION_SHARED_KEY = AtConstants.atEncryptionSharedKey;

@Deprecated('Use AtConstants.AT_ENCRYPTION_SELF_KEY instead')
const String AT_ENCRYPTION_SELF_KEY = AtConstants.atEncryptionSelfKey;

@Deprecated('Use AtConstants.AT_SIGNING_PRIVATE_KEY instead')
const String AT_SIGNING_PRIVATE_KEY = AtConstants.atSigningPrivateKey;

@Deprecated('Use AtConstants.AT_SIGNING_PUBLIC_KEY instead')
const String AT_SIGNING_PUBLIC_KEY = AtConstants.atSigningPublicKey;

@Deprecated('Use AtConstants.AT_CRAM_SECRET instead')
const String AT_CRAM_SECRET = AtConstants.atCramSecret;

@Deprecated('Use AtConstants.AT_CRAM_SECRET_DELETED instead')
const String AT_CRAM_SECRET_DELETED = AtConstants.atCramSecretDeleted;

@Deprecated('Use AtConstants.AT_SIGNING_KEYPAIR_GENERATED instead')
const String AT_SIGNING_KEYPAIR_GENERATED =
    AtConstants.atSigningKeypairGenerated;

@Deprecated('Use AtConstants.AT_STAT_ID instead')
const String AT_STAT_ID = AtConstants.statId;

@Deprecated('Use AtConstants.AT_TTL instead')
const String AT_TTL = AtConstants.ttl;

@Deprecated('Use AtConstants.AT_TTB instead')
const String AT_TTB = AtConstants.ttb;

@Deprecated('Use AtConstants.AT_TTR instead')
const String AT_TTR = AtConstants.ttr;

@Deprecated('Use AtConstants.AT_TTL_NOTIFICATION instead')
const String AT_TTL_NOTIFICATION = AtConstants.ttlNotification;

@Deprecated('Use AtConstants.AT_FROM_COMMIT_SEQUENCE instead')
const String AT_FROM_COMMIT_SEQUENCE = AtConstants.fromCommitSequence;

@Deprecated('Use AtConstants.AT_OPERATION instead')
const String AT_OPERATION = AtConstants.atOperation;

@Deprecated('Use AtConstants.AT_VALUE_REFERENCE instead')
const String AT_VALUE_REFERENCE = AtConstants.atValueReference;

@Deprecated('Use AtConstants.AT_REGEX instead')
const String AT_REGEX = AtConstants.regex;

@Deprecated('Use AtConstants.CONFIG_NEW instead')
const String CONFIG_NEW = AtConstants.configNew;

@Deprecated('Use AtConstants.FROM_AT_SIGN instead')
const String FROM_AT_SIGN = AtConstants.fromAtSign;

@Deprecated('Use AtConstants.TO_AT_SIGN instead')
const String TO_AT_SIGN = AtConstants.toAtSign;

@Deprecated('Use AtConstants.NOTIFICATION instead')
const String NOTIFICATION = AtConstants.notification;

@Deprecated('Use AtConstants.FROM instead')
const String FROM = AtConstants.from;

@Deprecated('Use AtConstants.TO instead')
const String TO = AtConstants.to;

@Deprecated('Use AtConstants.KEY instead')
const String KEY = AtConstants.key;

@Deprecated('Use AtConstants.EPOCH_MILLIS instead')
const String EPOCH_MILLIS = AtConstants.epochMilliseconds;

@Deprecated('Use AtConstants.MONITOR_STRICT_MODE instead')
const String MONITOR_STRICT_MODE = AtConstants.monitorStrictMode;

@Deprecated('Use AtConstants.MONITOR_MULTIPLEXED_MODE instead')
const String MONITOR_MULTIPLEXED_MODE = AtConstants.monitorMultiplexedMode;

@Deprecated('Use AtConstants.MONITOR_REGEX instead')
const String MONITOR_REGEX = AtConstants.monitorRegex;

@Deprecated('Use AtConstants.MONITOR_SELF_NOTIFICATIONS instead')
const String MONITOR_SELF_NOTIFICATIONS = AtConstants.monitorSelfNotifications;

@Deprecated('Use AtConstants.ID instead')
const String ID = AtConstants.id;

@Deprecated('Use AtConstants.OPERATION instead')
const String OPERATION = AtConstants.operation;

@Deprecated('Use AtConstants.SET_OPERATION instead')
const String SET_OPERATION = AtConstants.setOperation;

@Deprecated('Use AtConstants.UPDATE_META instead')
const String UPDATE_META = AtConstants.updateMeta;

@Deprecated('Use AtConstants.UPDATE_JSON instead')
const String UPDATE_JSON = AtConstants.updateJson;

@Deprecated('Use AtConstants.VALUE instead')
const String VALUE = AtConstants.value;

@Deprecated('Use AtConstants.UPDATE_ALL instead')
const String UPDATE_ALL = AtConstants.updateAll;

@Deprecated('Use AtConstants.CCD instead')
const String CCD = AtConstants.ccd;

@Deprecated('Use AtConstants.CACHED instead')
const String CACHED = AtConstants.cached;

@Deprecated('Use AtConstants.REFRESH_AT instead')
const String REFRESH_AT = AtConstants.refreshAt;

@Deprecated('Use AtConstants.IS_BINARY instead')
const String IS_BINARY = AtConstants.isBinary;

@Deprecated('Use AtConstants.IS_ENCRYPTED instead')
const String IS_ENCRYPTED = AtConstants.isEncrypted;

@Deprecated('Use AtConstants.IS_PUBLIC instead')
const String IS_PUBLIC = AtConstants.isPublic;

@Deprecated('Use AtConstants.ENCRYPTING_KEY_NAME instead')
const String ENCRYPTING_KEY_NAME = AtConstants.encryptingKeyName;

@Deprecated('Use AtConstants.ENCRYPTING_ALGO instead')
const String ENCRYPTING_ALGO = AtConstants.encryptingAlgo;

@Deprecated('Use AtConstants.IV_OR_NONCE instead')
const String IV_OR_NONCE = AtConstants.ivOrNonce;

@Deprecated('Use AtConstants.PUBLIC_DATA_SIGNATURE instead')
const String PUBLIC_DATA_SIGNATURE = AtConstants.publicDataSignature;

@Deprecated('Use AtConstants.SHARED_KEY_STATUS instead')
const String SHARED_KEY_STATUS = AtConstants.sharedKeyStatus;

@Deprecated('Use AtConstants.SHARED_KEY_ENCRYPTED instead')
const String SHARED_KEY_ENCRYPTED = AtConstants.sharedKeyEncrypted;

@Deprecated('Use AtConstants.SHARED_WITH_PUBLIC_KEY_CHECK_SUM instead')
const String SHARED_WITH_PUBLIC_KEY_CHECK_SUM =
    AtConstants.sharedWithPublicKeyCheckSum;

@Deprecated('Use AtConstants.SHARED_KEY_ENCRYPTED_ENCRYPTING_KEY_NAME instead')
const String SHARED_KEY_ENCRYPTED_ENCRYPTING_KEY_NAME =
    AtConstants.sharedKeyEncryptedEncryptingKeyName;

@Deprecated('Use AtConstants.SHARED_KEY_ENCRYPTED_ENCRYPTING_ALGO instead')
const String SHARED_KEY_ENCRYPTED_ENCRYPTING_ALGO =
    AtConstants.sharedKeyEncryptedEncryptingAlgo;

@Deprecated('Use AtConstants.FIRST_BYTE instead')
const String FIRST_BYTE = AtConstants.firstByte;

@Deprecated('Use AtConstants.CREATED_AT instead')
const String CREATED_AT = AtConstants.createdAt;

@Deprecated('Use AtConstants.UPDATED_AT instead')
const String UPDATED_AT = AtConstants.updatedAt;

@Deprecated('Use AtConstants.PRIORITY instead')
const String PRIORITY = AtConstants.priority;

@Deprecated('Use AtConstants.STRATEGY instead')
const String STRATEGY = AtConstants.strategy;

@Deprecated('Use AtConstants.NOTIFIER instead')
const String NOTIFIER = AtConstants.notifier;

@Deprecated('Use AtConstants.LATEST_N instead')
const String LATEST_N = AtConstants.latestN;

@Deprecated('Use AtConstants.SYSTEM instead')
const String SYSTEM = AtConstants.system;

@Deprecated('Use AtConstants.MESSAGE_TYPE instead')
const String MESSAGE_TYPE = AtConstants.messageType;

@Deprecated('Use AtConstants.PAGE instead')
const String PAGE = AtConstants.page;

@Deprecated('Use AtConstants.commitLogCompactionKey instead')
const String commitLogCompactionKey = AtConstants.commitLogCompactionKey;

@Deprecated('Use AtConstants.accessLogCompactionKey instead')
const String accessLogCompactionKey = AtConstants.accessLogCompactionKey;

@Deprecated('Use AtConstants.notificationCompactionKey instead')
const String notificationCompactionKey = AtConstants.notificationCompactionKey;

@Deprecated('Use AtConstants.bypassCache instead')
const String bypassCache = AtConstants.bypassCache;

@Deprecated('Use AtConstants.showHidden instead')
const String showHidden = AtConstants.showHidden;

@Deprecated('Use AtConstants.statsNotificationId instead')
const String statsNotificationId = AtConstants.statsNotificationId;

@Deprecated('Use AtConstants.ENCODING instead')
const String ENCODING = AtConstants.encoding;

@Deprecated('Use AtConstants.CLIENT_CONFIG instead')
const String CLIENT_CONFIG = AtConstants.clientConfig;

@Deprecated('Use AtConstants.VERSION instead')
const String VERSION = AtConstants.version;

@Deprecated('Use AtConstants.IS_LOCAL instead')
const String IS_LOCAL = AtConstants.isLocal;

@Deprecated('Use AtConstants.CLIENT_ID instead')
const String CLIENT_ID = AtConstants.clientId;

@Deprecated('Use AtConstants.APP_NAME instead')
const String APP_NAME = AtConstants.appName;

@Deprecated('Use AtConstants.APP_VERSION instead')
const String APP_VERSION = AtConstants.appVersion;

@Deprecated('Use AtConstants.PLATFORM instead')
const String PLATFORM = AtConstants.platform;

@Deprecated('Use AtConstants.enrollmentId instead')
const String enrollmentId = AtConstants.enrollmentId;

@Deprecated('Use AtConstants.keyType instead')
const String keyType = AtConstants.keyType;

@Deprecated('Use AtConstants.keyValue instead')
const String keyValue = AtConstants.keyValue;

@Deprecated('Use AtConstants.visibility instead')
const String visibility = AtConstants.visibility;

@Deprecated('Use AtConstants.namespace instead')
const String namespace = AtConstants.namespace;

@Deprecated('Use AtConstants.keyName instead')
const String keyName = AtConstants.keyName;

@Deprecated('Use AtConstants.deviceName instead')
const String deviceName = AtConstants.deviceName;

@Deprecated('Use AtConstants.encryptionKeyName instead')
const String encryptionKeyName = AtConstants.encryptionKeyName;

@Deprecated('Use AtConstants.apkamEncryptedDefaultPrivateKey instead')
const String apkamEncryptedDefaultPrivateKey =
    AtConstants.apkamEncryptedDefaultPrivateKey;

@Deprecated('Use AtConstants.apkamEncryptedDefaultSelfEncryptionKey instead')
const String apkamEncryptedDefaultSelfEncryptionKey =
    AtConstants.apkamEncryptedDefaultSelfEncryptionKey;

@Deprecated('Use AtConstants.apkamEncryptedSymmetricKey instead')
const String apkamEncryptedSymmetricKey =
    AtConstants.apkamEncryptedSymmetricKey;

@Deprecated('Use AtConstants.apkamPublicKey instead')
const String apkamPublicKey = AtConstants.apkamPublicKey;

@Deprecated('Use AtConstants.apkamNamespaces instead')
const String apkamNamespaces = AtConstants.apkamNamespaces;

@Deprecated('Use AtConstants.defaultEncryptionPrivateKey instead')
const String defaultEncryptionPrivateKey =
    AtConstants.defaultEncryptionPrivateKey;

@Deprecated('Use AtConstants.defaultSelfEncryptionKey instead')
const String defaultSelfEncryptionKey = AtConstants.defaultSelfEncryptionKey;

@Deprecated('Use AtConstants.enrollParams instead')
const String enrollParams = AtConstants.enrollParams;

==> at_commons-3.0.58.tar.gz: lib/src/at_constants_legacy.dart <==
// ignore_for_file: constant_identifier_names
part of 'at_constants.dart';

@Deprecated('Use AtConstants.atSign instead')
const String AT_SIGN = AtConstants.atSign;

@Deprecated('Use AtConstants.forAtSign instead')
const String FOR_AT_SIGN = AtConstants.forAtSign;

@Deprecated('Use AtConstants.atKey instead')
const String AT_KEY = AtConstants.atKey;

@Deprecated('Use AtConstants.atValue instead')
const String AT_VALUE = AtConstants.atValue;

@Deprecated('Use AtConstants.atDigest instead')
const String AT_DIGEST = AtConstants.atDigest;

@Deprecated('Use AtConstants.atPkamSignature instead')
const String AT_PKAM_SIGNATURE = AtConstants.atPkamSignature;

@Deprecated('Use AtConstants.atPkamSigningAlgo instead')
const String AT_PKAM_SIGNING_ALGO = AtConstants.atPkamSigningAlgo;

@Deprecated('Use AtConstants.atPkamHashingAlgo instead')
const String AT_PKAM_HASHING_ALGO = AtConstants.atPkamHashingAlgo;

@Deprecated('Use AtConstants.publicScopeParam instead')
const String PUBLIC_SCOPE_PARAM = AtConstants.publicScopeParam;

@Deprecated('Use AtConstants.atPkamPrivateKey instead')
const String AT_PKAM_PRIVATE_KEY = AtConstants.atPkamPrivateKey;

@Deprecated('Use AtConstants.atPkamPublicKey instead')
const String AT_PKAM_PUBLIC_KEY = AtConstants.atPkamPublicKey;

@Deprecated('Use AtConstants.atEncryptionPublicKey instead')
const String AT_ENCRYPTION_PUBLIC_KEY = AtConstants.atEncryptionPublicKey;

@Deprecated('Use AtConstants.atEncryptionPrivateKey instead')
const String AT_ENCRYPTION_PRIVATE_KEY = AtConstants.atEncryptionPrivateKey;

@Deprecated('Use AtConstants.atEncryptionSharedKey instead')
const String AT_ENCRYPTION_SHARED_KEY = AtConstants.atEncryptionSharedKey;

@Deprecated('Use AtConstants.atEncryptionSelfKey instead')
const String AT_ENCRYPTION_SELF_KEY = AtConstants.atEncryptionSelfKey;

@Deprecated('Use AtConstants.atSigningPrivateKey instead')
const String AT_SIGNING_PRIVATE_KEY = AtConstants.atSigningPrivateKey;

@Deprecated('Use AtConstants.atSigningPublicKey instead')
const String AT_SIGNING_PUBLIC_KEY = AtConstants.atSigningPublicKey;

@Deprecated('Use AtConstants.atCramSecret instead')
const String AT_CRAM_SECRET = AtConstants.atCramSecret;

@Deprecated('Use AtConstants.atCramSecretDeleted instead')
const String AT_CRAM_SECRET_DELETED = AtConstants.atCramSecretDeleted;

@Deprecated('Use AtConstants.atSigningKeypairGenerated instead')
const String AT_SIGNING_KEYPAIR_GENERATED =
    AtConstants.atSigningKeypairGenerated;

@Deprecated('Use AtConstants.statId instead')
const String AT_STAT_ID = AtConstants.statId;

@Deprecated('Use AtConstants.ttl instead')
const String AT_TTL = AtConstants.ttl;

@Deprecated('Use AtConstants.ttb instead')
const String AT_TTB = AtConstants.ttb;

@Deprecated('Use AtConstants.ttr instead')
const String AT_TTR = AtConstants.ttr;

@Deprecated('Use AtConstants.ttlNotification instead')
const String AT_TTL_NOTIFICATION = AtConstants.ttlNotification;

@Deprecated('Use AtConstants.fromCommitSequence instead')
const String AT_FROM_COMMIT_SEQUENCE = AtConstants.fromCommitSequence;

@Deprecated('Use AtConstants.atOperation instead')
const String AT_OPERATION = AtConstants.atOperation;

@Deprecated('Use AtConstants.atValueReference instead')
const String AT_VALUE_REFERENCE = AtConstants.atValueReference;

@Deprecated('Use AtConstants.regex instead')
const String AT_REGEX = AtConstants.regex;

@Deprecated('Use AtConstants.configNew instead')
const String CONFIG_NEW = AtConstants.configNew;

@Deprecated('Use AtConstants.fromAtSign instead')
const String FROM_AT_SIGN = AtConstants.fromAtSign;

@Deprecated('Use AtConstants.toAtSign instead')
const String TO_AT_SIGN = AtConstants.toAtSign;

@Deprecated('Use AtConstants.notification instead')
const String NOTIFICATION = AtConstants.notification;

@Deprecated('Use AtConstants.from instead')
const String FROM = AtConstants.from;

@Deprecated('Use AtConstants.to instead')
const String TO = AtConstants.to;

@Deprecated('Use AtConstants.key instead')
const String KEY = AtConstants.key;

@Deprecated('Use AtConstants.epochMilliseconds instead')
const String EPOCH_MILLIS = AtConstants.epochMilliseconds;

@Deprecated('Use AtConstants.monitorStrictMode instead')
const String MONITOR_STRICT_MODE = AtConstants.monitorStrictMode;

@Deprecated('Use AtConstants.monitorMultiplexedMode instead')
const String MONITOR_MULTIPLEXED_MODE = AtConstants.monitorMultiplexedMode;

@Deprecated('Use AtConstants.monitorRegex instead')
const String MONITOR_REGEX = AtConstants.monitorRegex;

@Deprecated('Use AtConstants.monitorSelfNotifications instead')
const String MONITOR_SELF_NOTIFICATIONS = AtConstants.monitorSelfNotifications;

@Deprecated('Use AtConstants.id instead')
const String ID = AtConstants.id;

@Deprecated('Use AtConstants.operation instead')
const String OPERATION = AtConstants.operation;

@Deprecated('Use AtConstants.setOperation instead')
const String SET_OPERATION = AtConstants.setOperation;

@Deprecated('Use AtConstants.updateMeta instead')
const String UPDATE_META = AtConstants.updateMeta;

@Deprecated('Use AtConstants.updateJson instead')
const String UPDATE_JSON = AtConstants.updateJson;

@Deprecated('Use AtConstants.value instead')
const String VALUE = AtConstants.value;

@Deprecated('Use AtConstants.updateAll instead')
const String UPDATE_ALL = AtConstants.updateAll;

@Deprecated('Use AtConstants.ccd instead')
const String CCD = AtConstants.ccd;

@Deprecated('Use AtConstants.cached instead')
const String CACHED = AtConstants.cached;

@Deprecated('Use AtConstants.refreshAt instead')
const String REFRESH_AT = AtConstants.refreshAt;

@Deprecated('Use AtConstants.isBinary instead')
const String IS_BINARY = AtConstants.isBinary;

@Deprecated('Use AtConstants.isEncrypted instead')
const String IS_ENCRYPTED = AtConstants.isEncrypted;

@Deprecated('Use AtConstants.isPublic instead')
const String IS_PUBLIC = AtConstants.isPublic;

@Deprecated('Use AtConstants.encryptingKeyName instead')
const String ENCRYPTING_KEY_NAME = AtConstants.encryptingKeyName;

@Deprecated('Use AtConstants.encryptingAlgo instead')
const String ENCRYPTING_ALGO = AtConstants.encryptingAlgo;

@Deprecated('Use AtConstants.ivOrNonce instead')
const String IV_OR_NONCE = AtConstants.ivOrNonce;

@Deprecated('Use AtConstants.publicDataSignature instead')
const String PUBLIC_DATA_SIGNATURE = AtConstants.publicDataSignature;

@Deprecated('Use AtConstants.sharedKeyStatus instead')
const String SHARED_KEY_STATUS = AtConstants.sharedKeyStatus;

@Deprecated('Use AtConstants.sharedKeyEncrypted instead')
const String SHARED_KEY_ENCRYPTED = AtConstants.sharedKeyEncrypted;

@Deprecated('Use AtConstants.sharedWithPublicKeyCheckSum instead')
const String SHARED_WITH_PUBLIC_KEY_CHECK_SUM =
    AtConstants.sharedWithPublicKeyCheckSum;

@Deprecated('Use AtConstants.sharedKeyEncryptedEncryptingKeyName instead')
const String SHARED_KEY_ENCRYPTED_ENCRYPTING_KEY_NAME =
    AtConstants.sharedKeyEncryptedEncryptingKeyName;

@Deprecated('Use AtConstants.sharedKeyEncryptedEncryptingAlgo instead')
const String SHARED_KEY_ENCRYPTED_ENCRYPTING_ALGO =
    AtConstants.sharedKeyEncryptedEncryptingAlgo;

@Deprecated('Use AtConstants.firstByte instead')
const String FIRST_BYTE = AtConstants.firstByte;

@Deprecated('Use AtConstants.createdAt instead')
const String CREATED_AT = AtConstants.createdAt;

@Deprecated('Use AtConstants.updatedAt instead')
const String UPDATED_AT = AtConstants.updatedAt;

@Deprecated('Use AtConstants.priority instead')
const String PRIORITY = AtConstants.priority;

@Deprecated('Use AtConstants.strategy instead')
const String STRATEGY = AtConstants.strategy;

@Deprecated('Use AtConstants.notifier instead')
const String NOTIFIER = AtConstants.notifier;

@Deprecated('Use AtConstants.latestN instead')
const String LATEST_N = AtConstants.latestN;

@Deprecated('Use AtConstants.system instead')
const String SYSTEM = AtConstants.system;

@Deprecated('Use AtConstants.messageType instead')
const String MESSAGE_TYPE = AtConstants.messageType;

@Deprecated('Use AtConstants.page instead')
const String PAGE = AtConstants.page;

@Deprecated('Use AtConstants.commitLogCompactionKey instead')
const String commitLogCompactionKey = AtConstants.commitLogCompactionKey;

@Deprecated('Use AtConstants.accessLogCompactionKey instead')
const String accessLogCompactionKey = AtConstants.accessLogCompactionKey;

@Deprecated('Use AtConstants.notificationCompactionKey instead')
const String notificationCompactionKey = AtConstants.notificationCompactionKey;

@Deprecated('Use AtConstants.bypassCache instead')
const String bypassCache = AtConstants.bypassCache;

@Deprecated('Use AtConstants.showHidden instead')
const String showHidden = AtConstants.showHidden;

@Deprecated('Use AtConstants.statsNotificationId instead')
const String statsNotificationId = AtConstants.statsNotificationId;

@Deprecated('Use AtConstants.encoding instead')
const String ENCODING = AtConstants.encoding;

@Deprecated('Use AtConstants.clientConfig instead')
const String CLIENT_CONFIG = AtConstants.clientConfig;

@Deprecated('Use AtConstants.version instead')
const String VERSION = AtConstants.version;

@Deprecated('Use AtConstants.isLocal instead')
const String IS_LOCAL = AtConstants.isLocal;

@Deprecated('Use AtConstants.clientId instead')
const String CLIENT_ID = AtConstants.clientId;

@Deprecated('Use AtConstants.appName instead')
const String APP_NAME = AtConstants.appName;

@Deprecated('Use AtConstants.appVersion instead')
const String APP_VERSION = AtConstants.appVersion;

@Deprecated('Use AtConstants.platform instead')
const String PLATFORM = AtConstants.platform;

@Deprecated('Use AtConstants.enrollmentId instead')
const String enrollmentId = AtConstants.enrollmentId;

@Deprecated('Use AtConstants.keyType instead')
const String keyType = AtConstants.keyType;

@Deprecated('Use AtConstants.keyValue instead')
const String keyValue = AtConstants.keyValue;

@Deprecated('Use AtConstants.visibility instead')
const String visibility = AtConstants.visibility;

@Deprecated('Use AtConstants.namespace instead')
const String namespace = AtConstants.namespace;

@Deprecated('Use AtConstants.keyName instead')
const String keyName = AtConstants.keyName;

@Deprecated('Use AtConstants.deviceName instead')
const String deviceName = AtConstants.deviceName;

@Deprecated('Use AtConstants.encryptionKeyName instead')
const String encryptionKeyName = AtConstants.encryptionKeyName;

@Deprecated('Use AtConstants.apkamEncryptedDefaultPrivateKey instead')
const String apkamEncryptedDefaultPrivateKey =
    AtConstants.apkamEncryptedDefaultPrivateKey;

@Deprecated('Use AtConstants.apkamEncryptedDefaultSelfEncryptionKey instead')
const String apkamEncryptedDefaultSelfEncryptionKey =
    AtConstants.apkamEncryptedDefaultSelfEncryptionKey;

@Deprecated('Use AtConstants.apkamEncryptedSymmetricKey instead')
const String apkamEncryptedSymmetricKey =
    AtConstants.apkamEncryptedSymmetricKey;

@Deprecated('Use AtConstants.apkamPublicKey instead')
const String apkamPublicKey = AtConstants.apkamPublicKey;

@Deprecated('Use AtConstants.apkamNamespaces instead')
const String apkamNamespaces = AtConstants.apkamNamespaces;

@Deprecated('Use AtConstants.defaultEncryptionPrivateKey instead')
const String defaultEncryptionPrivateKey =
    AtConstants.defaultEncryptionPrivateKey;

@Deprecated('Use AtConstants.defaultSelfEncryptionKey instead')
const String defaultSelfEncryptionKey = AtConstants.defaultSelfEncryptionKey;

@Deprecated('Use AtConstants.enrollParams instead')
const String enrollParams = AtConstants.enrollParams;
